@@ -1,3 +1,4 @@
+from .podcasts import parse_episode, parse_podcast
 from .songs import *
 
 
@@ -30,11 +31,14 @@ def parse_mixed_content(rows):
                         content = parse_related_artist(data)
                     elif page_type == "MUSIC_PAGE_TYPE_PLAYLIST":
                         content = parse_playlist(data)
-                else:
-                    data = nav(result, [MRLIR], True)
-                    if not data:
-                        continue
+                    elif page_type == "MUSIC_PAGE_TYPE_PODCAST_SHOW_DETAIL_PAGE":
+                        content = parse_podcast(data)
+                elif data := nav(result, [MRLIR], True):
                     content = parse_song_flat(data)
+                elif data := nav(result, [MMRIR], True):
+                    content = parse_episode(data)
+                else:
+                    continue
 
                 contents.append(content)
 
@@ -51,10 +55,9 @@ def parse_content_list(results, parse_func, key=MTRIR):
 
 
 def parse_album(result):
-    return {
+    album = {
         "title": nav(result, TITLE_TEXT),
         "type": nav(result, SUBTITLE),
-        "year": nav(result, SUBTITLE2, True),
         "artists": [parse_id_name(x) for x in nav(result, ["subtitle", "runs"]) if "navigationEndpoint" in x],
         "browseId": nav(result, TITLE + NAVIGATION_BROWSE_ID),
         "audioPlaylistId": nav(result, THUMBNAIL_OVERLAY, True),
@@ -62,6 +65,11 @@ def parse_album(result):
         "isExplicit": nav(result, SUBTITLE_BADGE_LABEL, True) is not None,
     }
 
+    if (year := nav(result, SUBTITLE2, True)) and year.isnumeric():
+        album["year"] = year
+
+    return album
+
 
 def parse_single(result):
     return {
@@ -109,7 +117,9 @@ def parse_video(result):
     videoId = nav(result, NAVIGATION_VIDEO_ID, True)
     if not videoId:
         videoId = next(
-            id for entry in nav(result, MENU_ITEMS) if nav(entry, MENU_SERVICE + QUEUE_VIDEO_ID, True)
+            video_id
+            for entry in nav(result, MENU_ITEMS)
+            if (video_id := nav(entry, MENU_SERVICE + QUEUE_VIDEO_ID, True))
         )
     return {
         "title": nav(result, TITLE_TEXT),
